#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2023 Mopi
set -o errexit

###
# A Castle Full of Cats
# send your bug reports to contact@dotslashplay.it
###

script_version=20230323.1

GAME_ID='a-castle-full-of-cats'
GAME_NAME='A Castle Full of Cats'

ARCHIVE_BASE_0='setup_a_castle_full_of_cats_1.07_gog_w_leaderboards_(63211).exe'
ARCHIVE_BASE_0_MD5='f0490493f27c903c5e07f87da5e1dde5'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='300000'
ARCHIVE_BASE_0_VERSION='1.07-gog63211'
ARCHIVE_BASE_0_URL='https://www.gog.com/en/game/a_castle_full_of_cats'

CONTENT_PATH_DEFAULT='.'
## The game fails to start if steam_api64.dll is missing.
CONTENT_GAME_BIN_FILES='
galaxyconfig.json
galaxy64.dll
steam_api64.dll
castle.exe'
CONTENT_GAME_DATA_FILES='
castle.pck'

USER_PERSISTENT_FILES='
*.cfg'

APP_MAIN_EXE='castle.exe'
APP_MAIN_ICON_WRESTOOL_OPTIONS='--type=14 --name=GODOT_ICON --language=1033'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"

# Load common functions

target_version='2.20'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
